abacusai.hosted_model_token — AbacusAI documentation

# abacusai.hosted_model_token

## Classes

`HostedModelToken` | A hosted model authentication token that is used to authenticate requests to an abacus hosted model

## Module Contents

class abacusai.hosted_model_token.HostedModelToken(client, createdAt=None, tag=None, trailingAuthToken=None, hostedModelTokenId=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  A hosted model authentication token that is used to authenticate requests to an abacus hosted model

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - createdAt (str) – When the token was created

    - tag (str) – A user-friendly tag for the API key.

    - trailingAuthToken (str) – The last four characters of the un-encrypted auth token

    - hostedModelTokenId (str) – The unique identifier attached to this authenticaion token

  created_at
  tag
  trailing_auth_token
  hosted_model_token_id
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict